@@ -1,4 +1,4 @@
-# $Id: Data.pm,v 1.20 1997/11/02 07:49:42 mike Exp $
+# $Id: Data.pm,v 1.21 1997/11/08 17:30:53 mike Exp mike $
 
 package Vend::Data;
 require Exporter;
@@ -504,7 +504,7 @@ my %Delimiter = (
 	2 => ["\n", "\n\n"],
 	3 => ["\n%%\n", "\n%%%\n"],
 	4 => ["CSV","\n"],
-	5 => ['\|', "\n"],
+	5 => ['|', "\n"],
 	6 => ["\t", "\n"],
 	7 => ["\t", "\n"],
 	8 => ["\t", "\n"],
@@ -512,7 +512,7 @@ my %Delimiter = (
 	'%%%' => ["\n%%\n", "\n%%%\n"],
 	'%%' => ["\n%%\n", "\n%%%\n"],
 	CSV => ["CSV","\n"],
-	PIPE => ['\|', "\n"],
+	PIPE => ['|', "\n"],
 	TAB => ["\t", "\n"],
 
 	);
